@@ -5,10 +5,7 @@ Pubsub package initialization.
 :license: BSD, see LICENSE_BSD_Simple.txt for details.
 """
 
-_PREVIOUS_RELEASE_DATE = "2014-02-01"
-_PREVIOUS_RELEASE_VER = "3.3.0"
-
-__version__ = "4.0.0"
+__version__ = "4.0.3"
 
 __all__ = [
     'pub',
